djmail
======

.. image:: https://img.shields.io/travis/bameda/djmail.svg?style=flat
    :target: https://travis-ci.org/bameda/djmail
  
.. image:: https://img.shields.io/pypi/v/djmail.svg?style=flat
    :target: https://pypi.python.org/pypi/djmail
  
.. image:: https://img.shields.io/pypi/dm/djmail.svg?style=flat
    :target: https://pypi.python.org/pypi/djmail
  
djmail is a BSD Licensed, simple and nonobstructive django email middleware.

http://bameda.github.io/djmail/
